@@ -5,6 +5,8 @@ package File::Find::Object::Rule;
 use strict;
 use warnings;
 
+use 5.008;
+
 use vars qw/$VERSION $AUTOLOAD/;
 use File::Spec;
 use Text::Glob 'glob_to_regex';
@@ -14,7 +16,7 @@ use File::Find::Object; # we're only wrapping for now
 use File::Basename;
 use Cwd;           # 5.00503s File::Find goes screwy with max_depth == 0
 
-$VERSION = '0.0300';
+$VERSION = '0.0306';
 
 use Class::XSAccessor
     accessors => {
@@ -44,6 +46,8 @@ sub import {
     }
 }
 
+=encoding utf8
+
 =head1 NAME
 
 File::Find::Object::Rule - Alternative interface to File::Find::Object
@@ -70,11 +74,11 @@ File::Find::Object::Rule - Alternative interface to File::Find::Object
 File::Find::Object::Rule is a friendlier interface to L<File::Find::Object> .
 It allows you to build rules which specify the desired files and directories.
 
-B<WARNING> : This module is a fork of version 0.30 of L<File::Find::Rule> 
-(which has been unmaintained for several years as of February, 2009), and may 
-still have some bugs due to its reliance on File::Find'isms. As such it is 
-considered Alpha software. Please report any problems with 
-L<File::Find::Object::Rule> to its RT CPAN Queue. 
+B<WARNING> : This module is a fork of version 0.30 of L<File::Find::Rule>
+(which has been unmaintained for several years as of February, 2009), and may
+still have some bugs due to its reliance on File::Find'isms. As such it is
+considered Alpha software. Please report any problems with
+L<File::Find::Object::Rule> to its RT CPAN Queue.
 
 =cut
 
@@ -131,7 +135,7 @@ sub new {
     my $referent = shift;
     my $class = ref $referent || $referent;
 
-    return 
+    return
     bless {
         rules    => [],  # [0]
         _subs     => [],  # [1]
@@ -346,8 +350,8 @@ sub any {
         rule => 'any',
         code => '(' . join( ' || ', map {
             "( " . $_->_compile($self->_subs()) . " )"
-        } @_ ) . ")",
-        args => \@_,
+        } @rulesets ) . ")",
+        args => \@rulesets,
     });
     $self;
 }
@@ -421,9 +425,11 @@ sub discard () {
 
 =item C<exec( \&subroutine( $shortname, $path, $fullname ) )>
 
-Allows user-defined rules.  Your subroutine will be invoked with C<$_>
-set to the current short name, and with parameters of the name, the
-path you're in, and the full relative filename.
+Allows user-defined rules.  Your subroutine will be invoked with parameters of
+the name, the path you're in, and the full relative filename.
+In addition, C<$_> is set to the current short name, but its use is
+discouraged since as opposed to File::Find::Rule, File::Find::Object::Rule
+does not cd to the containing directory.
 
 Return a true value if your rule matched.
 
@@ -661,7 +667,7 @@ sub start {
     my $code = 'sub {
         my $path_obj = shift;
         my $path = shift;
-        
+
         if (!defined($path_obj))
         {
             return;
@@ -702,7 +708,7 @@ sub start {
     $self->_match_cb($callback);
     $self->_call_find(\@paths);
 
-    return 1;
+    return $self;
 }
 
 
@@ -726,7 +732,7 @@ sub match {
         {
             $finder->set_traverse_to(
                 $preproc_cb->(
-                        $self, 
+                        $self,
                         [ @{$finder->get_current_node_files_list()} ]
                 )
             );
@@ -983,7 +989,7 @@ Corresponds to C<-k>.
 
 Corresponds to C<-l>.
 
-=head2 uid 
+=head2 uid
 
 See "stat tests".
 
@@ -1027,12 +1033,16 @@ L<File::Find::Object>, L<Text::Glob>, L<Number::Compare>, find(1)
 
 If you want to know about the procedural interface, see
 L<File::Find::Object::Rule::Procedural>, and if you have an idea for a neat
-extension L<File::Find::Object::Rule::Extending>
+extension, see  L<File::Find::Object::Rule::Extending> .
+
+L<Path::Class::Rule> ’s SEE ALSO contains a review of many directory traversal
+modules on CPAN, including L<File::Find::Object::Rule> and L<File::Find::Rule>
+(on which this module is based).
 
 =head1 KNOWN BUGS
 
-The tests don't run successfully when directly inside a Subversion checkout,
-due to the presence of C<.svn> directories. C<./Build disttest> or
+The tests don't run successfully when directly inside an old Subversion
+checkout, due to the presence of C<.svn> directories. C<./Build disttest> or
 C<./Build distruntest> run fine.
 
 =cut
